package com.kingfore.service.impl;


import com.kingfore.utils.DateUtils;
import com.mongodb.bulk.BulkWriteResult;
import com.mongodb.client.ListIndexesIterable;
import com.mongodb.client.MongoCollection;
import lombok.extern.java.Log;
import org.bson.Document;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.mongodb.core.BulkOperations;
import org.springframework.data.mongodb.core.MongoTemplate;
import org.springframework.data.mongodb.core.index.CompoundIndexDefinition;
import org.springframework.data.mongodb.core.index.Index;
import org.springframework.data.mongodb.core.query.Criteria;
import org.springframework.data.mongodb.core.query.Query;
import org.springframework.scheduling.annotation.EnableScheduling;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Service;

import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@Log
@Service
@EnableScheduling
public class HistoryImpl {

    @Autowired
    MongoTemplate mongoTemplate;

    @Scheduled(cron = "0 0,10,20,30,40,50 * * * ?")
    public void saveMongoDBGlHistory() {
        SimpleDateFormat sdt = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        SimpleDateFormat sym = new SimpleDateFormat("yyyyMM");
        String tableName="historyData"+sym.format(new Date());

        //查询得到所有的集合
        MongoCollection coll = mongoTemplate.getCollection(tableName);
        //查询这个集合的所有索引
        ListIndexesIterable<Document> lists = coll.listIndexes();
        int count = 0;
        for(Document d:lists){
            count++;
        }
        if(count== 1){
            //添加索引
            Document document = new Document();
            document.put("dataCode", 1);
            document.put("saveDate", -1);
            Index index = new CompoundIndexDefinition(document);
            index.named("codeDt");
            index.background();
            mongoTemplate.indexOps(tableName).ensureIndex(index);

            Document document1 = new Document();
            document1.put("dataCode", 1);
            document1.put("measurementId", 1);
            document1.put("saveDate", -1);
            Index index1 = new CompoundIndexDefinition(document);
            index.named("codeDt");
            index.background();
            mongoTemplate.indexOps(tableName).ensureIndex(index);
        }

        BulkOperations ops = mongoTemplate.bulkOps(BulkOperations.BulkMode.UNORDERED,  tableName);
        Query qu = Query.query(Criteria.where("history").is("是"));
        int saveCount=0;
        List<Map> deviceAll = mongoTemplate.find(qu, Map.class,"realData");
        for(Map m:deviceAll){
            Map hisMap = new HashMap();
            hisMap.put("dataCode",m.get("dataCode"));
            hisMap.put("measurementId",m.get("measurementId"));
            hisMap.put("measurementCode",m.get("measurementCode"));
            hisMap.put("deviceName",m.get("deviceName"));
            hisMap.put("onLine",m.get("onLine"));
            hisMap.put("value",m.get("value"));
            hisMap.put("dt",m.get("dt"));
            hisMap.put("sdt",new DateUtils().getCurrentTimeZERO());
            ops.insert(hisMap);
            saveCount++;
        }
        if (saveCount!=0){
            BulkWriteResult result = ops.execute();
            log.info("保存历史记录："+saveCount);
        }
    }
}
